require 'Clients'
require 'ClientsDlgUi'
require 'AjoutClientDlgUi'

# Class ClientsDlg
#
# definition : Manages the clients manager window (add, modify, delete)

class ClientsDlg < ClientsDlgUi

	# constructor
	def initialize(dataManager)
    super(nil,"ClientsDlgUi",true)
		@dataManager = dataManager
		@clients = @dataManager.clients
		@client_courant = nil
		@clients.clients.each {|client| @ListBoxClients.insertItem(client.raison_sociale+" / "+client.division+" / "+client.departement)}
		@nbClientsLbl.setText(@clients.length.to_s)
	end

	# Add a client to the current clients list. The new client gets displayed in the listbox as well.
	def addClient(raison_sociale, div, dep, adresse, cp, ville, contact, telephone)
		if @clients.getClient(raison_sociale,div,dep).nil? then
			@dataManager.addClient(raison_sociale, div, dep, adresse, cp, ville, contact, telephone)
			@ListBoxClients.insertItem(raison_sociale+" / "+div+" / "+dep)
			@nbClientsLbl.setText(@clients.length.to_s)
		else
			KDE::MessageBox::error(nil,i18n("Ce client existe déjà"),i18n("Erreur"))
		end
	end

	###################################################################
	#
	# SLOTS
	#
	###################################################################
	
	# Display the window that will enable the user to add a new client informations
  def addClientWin
    ajoutClientDlg = AjoutClientDlg.new(self)
		ajoutClientDlg.exec
  end
		
	# deletes from the list of clients, the one whose name is selected in the listbox
	def delClientWin
		nomclient = @ListBoxClients.currentText
		if nomclient!=nil then
			if !nomclient.empty? then
				if KDE::MessageBox::warningYesNo(nil,i18n("Attention ! Vous êtes sur le point de \
				supprimer un client et toutes les données qui lui sont relatives.\n\
				Confirmez vous la suppression ?"),"Suppression d'un client")==KDE::MessageBox::Yes() then
					rsociale, div, dep = nomclient.split(' / ')
					if dep.nil? then dep="" end
					if div.nil? then div="" end
					@dataManager.delClient(rsociale,div,dep)
					@ListBoxClients.removeItem(@ListBoxClients.currentItem)
					@nbClientsLbl.setText(@clients.length.to_s)
				end
			end
		else
			KDE::MessageBox::error(nil,i18n("Merci de sélectionner un client"),i18n("Erreur"))
		end
  end
	
	def updateInfos
		if (@ListBoxClients.currentText!=nil) then
			rsociale, div, dep = @ListBoxClients.currentText.split(' / ')
			if dep.nil? then dep="" end
			if div.nil? then div="" end
			@client_courant=@clients.getClient(rsociale,div,dep)
			@raisonsocialeLbl.setText(rsociale)
			@divisionLbl.setText(div)
			@departementLbl.setText(dep)
			@adresseLbl.setText(@client_courant.adresse)
			@codepostalLbl.setText(@client_courant.cp)
			@villeLbl.setText(@client_courant.ville)
			@telLbl.setText(@client_courant.telephone)
			@contactLbl.setText(@client_courant.contact)
		else
			@raisonsocialeLbl.setText("")
			@divisionLbl.setText("")
			@departementLbl.setText("")
			@adresseLbl.setText("")
			@codepostalLbl.setText("")
			@villeLbl.setText("")
			@telLbl.setText("")
			@contactLbl.setText("")
		end
	end
	
	def nextClient
		if (@ListBoxClients.currentItem!=-1) then
			if (@ListBoxClients.currentItem==@ListBoxClients.count()-1) then
				@ListBoxClients.setCurrentItem(0)
			else
				@ListBoxClients.setCurrentItem(@ListBoxClients.currentItem()+1)
			end
		end
	end
	
	def previousClient
		if (@ListBoxClients.currentItem!=-1) then
			if (@ListBoxClients.currentItem==0) then
				@ListBoxClients.setCurrentItem(@ListBoxClients.count()-1)
			else
				@ListBoxClients.setCurrentItem(@ListBoxClients.currentItem-1)
			end
		end
	end
end


# Class AjoutClientDlg
#
# definition : A graphical window to enter informations about a new client

class AjoutClientDlg < AjoutClientDlgUi
	
	# constructor
	def initialize(clientsDlg)
		@clientsDlg = clientsDlg
		super(nil,"ajout_client_dlg",true)
	end
	
	# if every field required is filled, then update the clients list and closes the window
	# otherwise, it displays an error message
	def accept
		if (@nomEdt.text.empty? or @adresseEdt.text.empty? or @codepostalEdt.text.empty? or @villeEdt.text.empty? or @contactEdt.text.empty? or @telEdt.text.empty?) then
			KDE::MessageBox::error(nil,i18n("Merci de remplir tous les champs requis"),i18n("Erreur"))
		else
			if (@nomEdt.text.include? "/" or @divisionEdt.text.include? "/" or @departementEdt.text.include? "/") then
				KDE::MessageBox::error(nil,i18n("Merci de ne pas utiliser le caractère '/' pour la raison sociale, la division ou bien encore le département"),i18n("Erreur"))
			else
				@clientsDlg.addClient(@nomEdt.text,@divisionEdt.text,@departementEdt.text,@adresseEdt.text,@codepostalEdt.text,@villeEdt.text,@contactEdt.text,@telEdt.text)
				close(true)
			end
		end
	end
end

