require 'ContratsDlgUi'
require 'Contrats'
require 'AjoutContratExpDlgUi'
require 'AjoutContratSupDlgUi'
require 'AjoutContratProdDlgUi'
require 'Config'

# Class ContratsDlg
#
# definition : Manages the contrats manager window

class ContratsDlg < ContratsDlgUi
	
	# constructor
	def initialize(dataManager)
		super(nil,"contrats_dlg",true)
		@dataManager = dataManager
		@contrat_exp_courant = nil
		@contrat_sup_courant = nil
		@contrat_prod_courant = nil
		@contratsExpertise = @dataManager.contratsExpertise
		@contratsSupport = @dataManager.contratsSupport
		@contratsProduits = @dataManager.contratsProduits
		@contratsExpertise.contrats.each do |contrat|
			@expertiseLbx.insertItem(contrat.reference+", "+contrat.titre)
		end
		@contratsSupport.contrats.each do |contrat|
			@supportLbx.insertItem(contrat.reference+", "+contrat.titre)
		end
		@contratsProduits.contrats.each do |contrat|
			@produitsLbx.insertItem(contrat.reference+", "+contrat.titre)
		end
		@triExpCbx.insertStringList(@dataManager.getTriExp)
		@triSupCbx.insertStringList(@dataManager.getTriSup)
		@triProdCbx.insertStringList(@dataManager.getTriProd)
		@nbExpLbl.setText(@contratsExpertise.length.to_s)
		@nbSupLbl.setText(@contratsSupport.length.to_s)
		@nbProdLbl.setText(@contratsProduits.length.to_s)
	end
	
	def addContratExp(ref,titre,client,commercial,montant,desc,date_deb,date_fin_prevue)
		if @contratsExpertise.getContrat(ref).nil? then
			@dataManager.addContratExp(ref,titre,client,commercial,montant,desc,date_deb,date_fin_prevue)
			@expertiseLbx.insertItem(ref+", "+titre)
			@nbExpLbl.setText(@contratsExpertise.length.to_s)
			@expertiseLbx.setCurrentItem(@expertiseLbx.count-1)
		else
			KDE::MessageBox::error(nil,i18n("Ce contrat d'expertise existe déjà"),i18n("Erreur"))
		end
	end
	
	def addContratSup(ref,titre,contratExp,client,commercial,montant,date_deb,date_fin,desc)
		if @contratsSupport.getContrat(ref).nil? then
			@dataManager.addContratSup(ref,titre,contratExp,client,commercial,montant,date_deb,date_fin,desc)
			@supportLbx.insertItem(ref+", "+titre)
			@nbSupLbl.setText(@contratsSupport.length.to_s)
			@supportLbx.setCurrentItem(@supportLbx.count-1)
		else
			KDE::MessageBox::error(nil,i18n("Ce contrat de support existe déjà"),i18n("Erreur"))
		end
	end
	
	def addContratProd(ref,titre,contratExp,client,commercial,montant,marge,designation,date)
		if @contratsProduits.getContrat(ref).nil? then
			@dataManager.addContratProd(ref,titre,contratExp,client,commercial,montant,marge,designation,date)
			@produitsLbx.insertItem(ref+", "+titre)
			@nbProdLbl.setText(@contratsProduits.length.to_s)
			@produitsLbx.setCurrentItem(@produitsLbx.count-1)
		else
			KDE::MessageBox::error(nil,i18n("Ce contrat produit existe déjà"),i18n("Erreur"))
		end
	end
	
	###################################################################
	#
	# SLOTS
	#
	###################################################################
	
	def addExpWin
		if @dataManager.clients.length==0 then
			KDE::MessageBox::error(nil,i18n("Vous devez enregistrer au moins un client au préalable"),i18n("Erreur"))
			return
		elsif @dataManager.ressources.getCommerciaux.length==0 then
			KDE::MessageBox::error(nil,i18n("Vous devez enregistrer au moins une ressource commerciale au préalable"),i18n("Erreur"))
			return
		end
		ajoutContratExpDlg = AjoutContratExpDlg.new(self)
		listeClients=[]
		@dataManager.clients.clients.each do |client|
			listeClients.push(client.raison_sociale+" / "+client.division+" / "+client.departement)
		end
		ajoutContratExpDlg.clientCbx.insertStringList(listeClients)
		listeCommerciaux=[]
		@dataManager.ressources.getCommerciaux.each do |commercial|
			listeCommerciaux.push(commercial.nom+", "+commercial.prenom)
		end
		ajoutContratExpDlg.commercialCbx.insertStringList(listeCommerciaux)
		ajoutContratExpDlg.exec
	end
	
	def delExpWin
	end
	
	def addSupWin
		if @dataManager.clients.length==0 then
			KDE::MessageBox::error(nil,i18n("Vous devez enregistrer au moins un client au préalable"),i18n("Erreur"))
			return
		elsif @dataManager.ressources.getCommerciaux.length==0 then
			KDE::MessageBox::error(nil,i18n("Vous devez enregistrer au moins une ressource commerciale au préalable"),i18n("Erreur"))
			return
		end
		ajoutContratSupDlg = AjoutContratSupDlg.new(self)
		listeContrats=[Config::AUCUN]
		@contratsExpertise.contrats.each do |contrat|
			listeContrats.push(contrat.reference+", "+contrat.titre)
		end
		ajoutContratSupDlg.contratExpCbx.insertStringList(listeContrats)
		listeClients=[]
		@dataManager.clients.clients.each do |client|
			listeClients.push(client.raison_sociale+" / "+client.division+" / "+client.departement)
		end
		ajoutContratSupDlg.clientCbx.insertStringList(listeClients)
		listeCommerciaux=[]
		@dataManager.ressources.getCommerciaux.each do |commercial|
			listeCommerciaux.push(commercial.nom+", "+commercial.prenom)
		end
		ajoutContratSupDlg.commercialCbx.insertStringList(listeCommerciaux)
		ajoutContratSupDlg.exec
	end
	
	def delSupWin
	end
	
	def addProdWin
		if @dataManager.clients.length==0 then
			KDE::MessageBox::error(nil,i18n("Vous devez enregistrer au moins un client au préalable"),i18n("Erreur"))
			return
		elsif @dataManager.ressources.getCommerciaux.length==0 then
			KDE::MessageBox::error(nil,i18n("Vous devez enregistrer au moins une ressource commerciale au préalable"),i18n("Erreur"))
			return
		end
		ajoutContratProdDlg = AjoutContratProdDlg.new(self)
		listeContrats=[Config::AUCUN]
		@contratsExpertise.contrats.each do |contrat|
			listeContrats.push(contrat.reference+", "+contrat.titre)
		end
		ajoutContratProdDlg.contratExpCbx.insertStringList(listeContrats)
		listeClients=[]
		@dataManager.clients.clients.each do |client|
			listeClients.push(client.raison_sociale+" / "+client.division+" / "+client.departement)
		end
		ajoutContratProdDlg.clientCbx.insertStringList(listeClients)
		listeCommerciaux=[]
		@dataManager.ressources.getCommerciaux.each do |commercial|
			listeCommerciaux.push(commercial.nom+", "+commercial.prenom)
		end
		ajoutContratProdDlg.commercialCbx.insertStringList(listeCommerciaux)
		ajoutContratProdDlg.exec
	end
	
	def delProdWin
	end
	
end

class AjoutContratExpDlg < AjoutContratExpDlgUi

	# constructor
	def initialize(contratDlg)
		super(nil,"ajout_contrat_exp",true)
		@contratDlg = contratDlg
	end
	
	def accept
		dateDeb = Date.new(@debutDpicker.date.year,@debutDpicker.date.month,@debutDpicker.date.day)
		dateFin = Date.new(@finDpicker.date.year,@finDpicker.date.month,@finDpicker.date.day)
		if (@referenceEdt.text.empty? or @titreEdt.text.empty? or @descTEdt.text.empty?) then
			KDE::MessageBox::error(nil,i18n("Merci de remplir tous les champs"),i18n("Erreur"))
		else
			if (@referenceEdt.text.include? "," or @titreEdt.text.include? ",") then
				KDE::MessageBox::error(nil,i18n("Merci de n'utiliser le caractère réservé ',' ni dans la référence ni dans le titre"),i18n("Erreur"))
			elsif dateDeb > dateFin then
				KDE::MessageBox::error(nil,i18n("Merci de réparer l'incohérence de date : la date de début est postérieure à la date de fin"),i18n("Erreur"))
			else
				@contratDlg.addContratExp(@referenceEdt.text,@titreEdt.text,@clientCbx.currentText,@commercialCbx.currentText,@montantNIpt.value,@descTEdt.text,dateDeb,dateFin)
				close(true)
			end
		end
	end
end

class AjoutContratSupDlg < AjoutContratSupDlgUi

	# constructor
	def initialize(contratDlg)
		super(nil,"ajout_contrat_sup",true)
		@contratDlg = contratDlg
	end
	
	def accept
		dateDeb = Date.new(@debutDpicker.date.year,@debutDpicker.date.month,@debutDpicker.date.day)
		dateFin = Date.new(@finDpicker.date.year,@finDpicker.date.month,@finDpicker.date.day)
		if (@referenceEdt.text.empty? or @titreEdt.text.empty? or @descTEdt.text.empty?) then
			KDE::MessageBox::error(nil,i18n("Merci de remplir tous les champs"),i18n("Erreur"))
		else
			if (@referenceEdt.text.include? "," or @titreEdt.text.include? ",") then
				KDE::MessageBox::error(nil,i18n("Merci de n'utiliser le caractère réservé ',' ni dans la référence ni dans le titre"),i18n("Erreur"))
			elsif dateDeb > dateFin then
				KDE::MessageBox::error(nil,i18n("Merci de réparer l'incohérence de date : la date de début est postérieure à la date de fin"),i18n("Erreur"))
			else			
				@contratDlg.addContratSup(@referenceEdt.text,@titreEdt.text,@contratExpCbx.currentText,@clientCbx.currentText,@commercialCbx.currentText,@montantNIpt.value,dateDeb,dateFin,@descTEdt.text)
				close(true)
			end
		end
	end
end

class AjoutContratProdDlg < AjoutContratProdDlgUi

	# constructor
	def initialize(contratDlg)
		super(nil,"ajout_contrat_prod",true)
		@contratDlg = contratDlg
	end
	
	def accept
		date = Date.new(@dateDpicker.date.year,@dateDpicker.date.month,@dateDpicker.date.day)
		if (@referenceEdt.text.empty? or @titreEdt.text.empty? or @designationTEdt.text.empty?) then
			KDE::MessageBox::error(nil,i18n("Merci de remplir tous les champs"),i18n("Erreur"))
		else
			if (@referenceEdt.text.include? "," or @titreEdt.text.include? ",") then
				KDE::MessageBox::error(nil,i18n("Merci de n'utiliser le caractère réservé ',' ni dans la référence ni dans le titre"),i18n("Erreur"))
			else	
				@contratDlg.addContratProd(@referenceEdt.text,@titreEdt.text,@contratExpCbx.currentText,@clientCbx.currentText,@commercialCbx.currentText,@montantNIpt.value,@margeNIpt.value,@designationTEdt.text,date)
				close(true)
			end
		end
	end
end