require 'date'

# Classe Propositions
#
# dfinition : gre la collection de propositions reprsentes par des instances de classe Proposition

class Propositions
	attr_reader :propositions

	def initialize
		@propositions = []
	end
	
	# Ajoute une proposition  la liste de propositions
	def addProposition(ref,titre,desc,date,montant,proba)
		@propositions.push(Proposition.new(ref,titre,desc,date, montant, "en cours", proba))
	end
	
	# Supprime la proposition dont la rfrence est <ref> de la liste de propositions
	def delProposition(ref)
		@propositions.delete_if {|proposition| proposition.reference==ref}
	end
end

# Classe Proposition
#
# dfinition : classe mre qui regroupe les attributs communs  des propositions
# de support, d'ingnierie et de produits
# attributs :
# - rfrence : rfrence de la proposition (sera utilise si la proposition se transforme en contrat)
# - titre : titre de la proposition
# - description : succinte description du contenu de la proposition
# - date : date  laquelle la proposition a t faite
# - montant : le prix qui a t donn associ  la proposition
# - etat : l'tat de la proposition : "en cours","gagne", "perdue"
# - proba : probabilit de ralisation de la proposition (ex : 0,1)

class Proposition
	attr_reader :reference, :titre, :description, :date, :montant, :etat, :probabilite
	
	# constructeur
	def initialize(ref,titre,desc,date,montant,etat,proba)
		@reference = ref
		@titre = titre
		@description = desc
		@date = date
		@montant = montant
		@etat = etat
		@proba = proba
	end
	
	def to_s
		"Rfrence : #{@reference}\nTitre : #{@titre}\nDate : #{@date}\nDescription :\n#{@description}\nMontant : #{@montant}\nEtat : #{@etat}\nProbabilit : #{@proba}"
	end
end

# Classe Propale_ingenierie
# 
# dfinition : 
# - estimation_jours : le nombre de jours d'ingnierie estim pour le projet
class Propale_ingenierie < Proposition

	# constructeur
	def initialize(ref,titre,desc,date,montant,etat,proba,jours)
		super(ref,titre,desc,date,montant,etat,proba)
		@estimation_jours = jours
	end
	
	def to_s
		"Type : ingnierie\nNb jours estims : #{@estimation_jours}\n" + super
	end
end

# Classe Propale_support
# 
# dfinition : 
# - type_support : Le type de support propos ( dfinir)
class Propale_support < Proposition
	
	# constructeur
	def initialize(ref,titre,desc,date,montant,etat,proba,type)
		super(ref,titre,desc,date,montant,etat,proba)
		@type_support = type
	end
	
	def to_s
		"Type : support\nType de support : #{@type_support}\n" + super
	end
end

# Classe Propale_produit
# 
# dfinition : 
# - marge_produit : La marge prvue sur le produit propos
class Propale_produit < Proposition
	
	# constructeur
	def initialize(ref,titre,desc,date,montant,etat,proba,marge)
		super(ref,titre,desc,date,montant,etat,proba)
		@marge_produit = marge
	end
	
	def to_s
		"Type : produit\nMarge attendue : #{@marge_produit}\n" + super
	end
end