require 'Ressources'
require 'RessourcesDlgUi'
require 'AjoutRessourceDlgUi'
require 'Config'

# Class RessourcesDlg
#
# definition : Manages the human resources manager window

class RessourcesDlg < RessourcesDlgUi
	
	# constructor
	def initialize(dataManager)
		super(nil,"ressources_dlg",true)
		@dataManager = dataManager
		@ressources = @dataManager.ressources
		@commercial_courant = nil
		@technicien_courant = nil
		@ressources.getCommerciaux.each do |ressource| 
			@ListBoxCommerciaux.insertItem(ressource.nom+", "+ressource.prenom)
		end
		@ressources.getTechniciens.each do |ressource| 
			@ListBoxTechniciens.insertItem(ressource.nom+", "+ressource.prenom)
		end
		@nbCommerciauxLbl.setText(@ressources.getCommerciaux.length.to_s)
		@nbTechniciensLbl.setText(@ressources.getTechniciens.length.to_s)
		@ListBoxCommerciaux.setCurrentItem(0)
		@ListBoxTechniciens.setCurrentItem(0)
	end
	
	def addRessource(nom,prenom,fonction,salaire)
		if @ressources.getRessource(nom,prenom,fonction).nil? then
			@dataManager.addRessource(nom,prenom,fonction,salaire)
			if fonction==Config::COMMERCIAL then
				@ListBoxCommerciaux.insertItem(nom+", "+prenom)
				@nbCommerciauxLbl.setText(@ressources.getCommerciaux.length.to_s)
				@ListBoxCommerciaux.setCurrentItem(@ListBoxCommerciaux.count-1)
			elsif fonction==Config::TECHNICIEN then
				@ListBoxTechniciens.insertItem(nom+", "+prenom)
				@nbTechniciensLbl.setText(@ressources.getTechniciens.length.to_s)
				@ListBoxTechniciens.setCurrentItem(@ListBoxTechniciens.count-1)
			else
				puts "Error : Unknown resource function"
			end
		else
			KDE::MessageBox::error(nil,i18n("Cette ressource existe déjà"),i18n("Erreur"))
		end
	end

	###################################################################
	#
	# SLOTS
	#
	###################################################################
	
	def updateInfosCommercial
		commercial = @ListBoxCommerciaux.currentText
		unless commercial.nil? then
			nomComm, prenomComm = commercial.split(', ')
			@commercial_courant=@ressources.getRessource(nomComm,prenomComm,Config::COMMERCIAL)
			@nomCommLbl.setText(@commercial_courant.nom)
			@prenomCommLbl.setText(@commercial_courant.prenom)
			@salaireCommLbl.setText(@commercial_courant.salaire.to_i.to_s+" euros")
		else
			@nomCommLbl.setText("")
			@prenomCommLbl.setText("")
			@salaireCommLbl.setText("")
		end
	end
	
	def updateInfosTechnicien
		technicien = @ListBoxTechniciens.currentText
		unless technicien.nil? then
			nomTech, prenomTech = technicien.split(', ')
			@technicien_courant=@ressources.getRessource(nomTech,prenomTech,Config::TECHNICIEN)
			@nomTechLbl.setText(@technicien_courant.nom)
			@prenomTechLbl.setText(@technicien_courant.prenom)
			@salaireTechLbl.setText(@technicien_courant.salaire.to_i.to_s+" euros")
		else
			@nomTechLbl.setText("")
			@prenomTechLbl.setText("")
			@salaireTechLbl.setText("")
		end
	end	

	def addCommercialWin
		ajoutRessourceDlg = AjoutRessourceDlg.new(self)
		ajoutRessourceDlg.fonctionCbx.insertStringList(@dataManager.getFonctions)
		ajoutRessourceDlg.fonctionCbx.setCurrentItem(@dataManager.getFonctions.index(Config::COMMERCIAL))
		ajoutRessourceDlg.exec
	end
	
	def delCommercialWin
		commercial = @ListBoxCommerciaux.currentText
		if commercial!=nil then
			unless commercial.empty? then
				if KDE::MessageBox::warningYesNo(nil,i18n("Attention ! Vous êtes sur le point de \
				supprimer un commercial et toutes les données qui lui sont relatives.\n\
				Confirmez vous la suppression ?"),"Suppression d'un commercial")==KDE::MessageBox::Yes() then
					nom, prenom = commercial.split(', ')
					@dataManager.delRessource(nom, prenom,Config::COMMERCIAL)
					@ListBoxCommerciaux.removeItem(@ListBoxCommerciaux.currentItem)
					@nbCommerciauxLbl.setText(@ressources.getCommerciaux.length.to_s)
				end
			end
		else
			KDE::MessageBox::error(nil,i18n("Merci de sélectionner un commercial"),i18n("Erreur"))
		end
	end
	
	def addTechnicienWin
		ajoutRessourceDlg = AjoutRessourceDlg.new(self)
		ajoutRessourceDlg.fonctionCbx.insertStringList(@dataManager.getFonctions)
		ajoutRessourceDlg.fonctionCbx.setCurrentItem(@dataManager.getFonctions.index(Config::TECHNICIEN))
		ajoutRessourceDlg.exec
	end
	
	def delTechnicienWin
		technicien = @ListBoxTechniciens.currentText
		if technicien!=nil then
			unless technicien.empty? then
				if KDE::MessageBox::warningYesNo(nil,i18n("Attention ! Vous êtes sur le point de \
				supprimer un technicien et toutes les données qui lui sont relatives.\n\
				Confirmez vous la suppression ?"),"Suppression d'un technicien")==KDE::MessageBox::Yes() then
					nom, prenom = technicien.split(', ')
					@dataManager.delRessource(nom, prenom, Config::TECHNICIEN)
					@ListBoxTechniciens.removeItem(@ListBoxTechniciens.currentItem)
					@nbTechniciensLbl.setText(@ressources.getTechniciens.length.to_s)
				end
			end
		else
			KDE::MessageBox::error(nil,i18n("Merci de sélectionner un technicien"),i18n("Erreur"))
		end
	end
	
	def nextCommercial
		if (@ListBoxCommerciaux.currentItem!=-1) then
			if (@ListBoxCommerciaux.currentItem==@ListBoxCommerciaux.count()-1) then
				@ListBoxCommerciaux.setCurrentItem(0)
			else
				@ListBoxCommerciaux.setCurrentItem(@ListBoxCommerciaux.currentItem()+1)
			end
		end
	end
	
	def previousCommercial
		if (@ListBoxCommerciaux.currentItem!=-1) then
			if (@ListBoxCommerciaux.currentItem==0) then
				@ListBoxCommerciaux.setCurrentItem(@ListBoxCommerciaux.count()-1)
			else
				@ListBoxCommerciaux.setCurrentItem(@ListBoxCommerciaux.currentItem-1)
			end
		end
	end
	
	def nextTechnicien
		if (@ListBoxTechniciens.currentItem!=-1) then
			if (@ListBoxTechniciens.currentItem==@ListBoxTechniciens.count()-1) then
				@ListBoxTechniciens.setCurrentItem(0)
			else
				@ListBoxTechniciens.setCurrentItem(@ListBoxTechniciens.currentItem()+1)
			end
		end
	end
	
	def previousTechnicien
		if (@ListBoxTechniciens.currentItem!=-1) then
			if (@ListBoxTechniciens.currentItem==0) then
				@ListBoxTechniciens.setCurrentItem(@ListBoxTechniciens.count()-1)
			else
				@ListBoxTechniciens.setCurrentItem(@ListBoxTechniciens.currentItem-1)
			end
		end
	end
end



class AjoutRessourceDlg < AjoutRessourceDlgUi

	# constructor
	def initialize(ressourceDlg)
		super(nil,"ajout_ressource",true)
		@ressourceDlg = ressourceDlg
	end
	
	# if every field is field, then update the clients list and closes the window
	# otherwise, it displays an error message
	def accept
		if (@nomEdt.text.empty? or @prenomEdt.text.empty?) then
			KDE::MessageBox::error(nil,i18n("Merci de remplir tous les champs"),i18n("Erreur"))
		else
			if (@nomEdt.text.include? "," or @prenomEdt.text.include? ",") then
				KDE::MessageBox::error(nil,i18n("Merci de n'utiliser le caractère réservé ',' ni dans le nom ni dans le prénom"),i18n("Erreur"))
			else
				@ressourceDlg.addRessource(@nomEdt.text,@prenomEdt.text,@fonctionCbx.currentText,@salaireNipt.value)
				close(true)
			end
		end
	end
end